# Changelog

## 0.1.0-alpha.4 (2025-07-12)

Full Changelog: [v0.1.0-alpha.3...v0.1.0-alpha.4](https://github.com/bluehive-health/bluehive-sdk-python/compare/v0.1.0-alpha.3...v0.1.0-alpha.4)

### Bug Fixes

* **client:** don't send Content-Type header on GET requests ([2c2bbb9](https://github.com/bluehive-health/bluehive-sdk-python/commit/2c2bbb99f7774aeb7eaaf955c188819794376adc))


### Chores

* **readme:** fix version rendering on pypi ([933fd60](https://github.com/bluehive-health/bluehive-sdk-python/commit/933fd60ff623cb82bc3017b5180c73fea804b72a))

## 0.1.0-alpha.3 (2025-07-10)

Full Changelog: [v0.1.0-alpha.2...v0.1.0-alpha.3](https://github.com/bluehive-health/bluehive-sdk-python/compare/v0.1.0-alpha.2...v0.1.0-alpha.3)

### Bug Fixes

* **parsing:** correctly handle nested discriminated unions ([15d178d](https://github.com/bluehive-health/bluehive-sdk-python/commit/15d178d4a1ca566cff253150d6ee4e0ea55d9e2b))

## 0.1.0-alpha.2 (2025-07-09)

Full Changelog: [v0.1.0-alpha.1...v0.1.0-alpha.2](https://github.com/bluehive-health/bluehive-sdk-python/compare/v0.1.0-alpha.1...v0.1.0-alpha.2)

### Chores

* **internal:** bump pinned h11 dep ([77b8495](https://github.com/bluehive-health/bluehive-sdk-python/commit/77b84958a99fea04743c4aaf300731dedc61da3a))
* **package:** mark python 3.13 as supported ([e58a361](https://github.com/bluehive-health/bluehive-sdk-python/commit/e58a36108c35a42d3f665ac1972fe20d4afd7c54))

## 0.1.0-alpha.1 (2025-07-06)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/bluehive-health/bluehive-sdk-python/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** api update ([90448d7](https://github.com/bluehive-health/bluehive-sdk-python/commit/90448d76356b411bb678274c923ebf0d5d904218))


### Chores

* configure new SDK language ([d15c2c6](https://github.com/bluehive-health/bluehive-sdk-python/commit/d15c2c680ba6c46102b5b37fb3d9f31a66e5ba8d))
* update SDK settings ([4e5fa24](https://github.com/bluehive-health/bluehive-sdk-python/commit/4e5fa2407f9fcf01e7c25d040b4656246cb8d492))
* update SDK settings ([a9c06ff](https://github.com/bluehive-health/bluehive-sdk-python/commit/a9c06ff66ca3d06d5c6d1dc35458fbd387a5b7bc))
